@@ -19,13 +19,23 @@ def create_timer(id: str = None):
 class Timer:
     def __init__(self) -> None:
         self.progress_total = 0
-        self.progress_current = 0
+        self._progress_current = 0
+        self.progress_last = 0
         self.start()
 
     def start(self) -> float:
         self.time_start = time.time()
         return self.time_start
 
+    @property
+    def progress_current(self):
+        return self._progress_current
+
+    @progress_current.setter
+    def progress_current(self, value):
+        self.progress_last = self.progress_current
+        self._progress_current = value
+
     @property
     def spent(self) -> float:
         return time.time() - self.time_start
@@ -38,9 +48,20 @@ class Timer:
 
     @property
     def progress_description(self) -> str:
-        p = self.progress
-        d = math.ceil(p * 10000) / 100
-        return f'{d}%'
+        '''
+        get description with format `progress%`
+        '''
+        p = self.progress * 100
+        v = '{:.2f}'.format(p)
+        return f'{v}%'
+
+    @property
+    def progress_description_with_value(self) -> str:
+        '''
+        get description with format `value/total(progress%)`
+        '''
+        d = self.progress_description
+        return f'{self.progress_current}/{self.progress_total}({self.progress_description})'
 
     @property
     def left_time(self) -> float:
